Learn R Programming

mbrglm (version 0.0.1)

endo:

Description

Study of 79 primarily diagnosed cases of endometrial cancer in order to explain the histology of the endometrium by putative risk factors. The endo data frame has 79 rows and 4 columns. Variable histology, HG. Three risk factors: variable neovasculization, NV, variable pulsatility index, PI and variable endometrium height, EH.

Usage

data("endo")

Arguments

Format

A data frame with 79 observations on the following 4 variables.
NV
a factor with two levels 1 (present) and 0 (absent)
PI
pulsatility index of arteria uterina
EH
endometrium height
HG
a factor with two levels classified as either 0 (grading 0-II) or 1 (grading III-IV)

Examples

Run this code
data(endo)
glm(HG~NV+PI+EH,family=binomial,data=endo)
mbrglm(HG~NV+PI+EH,family=binomial,data=endo)

Run the code above in your browser using DataLab