mbrglm
fitting. Typically only used when calling mbrglm or mbrglm.fit.mbrglm.control(mbr.epsilon = 1e-06, mbr.maxit = 500,
mbr.trace = FALSE, ...)mbrglm.fit.mbrglm.fit.mbrglmis by default passed to the control argument of mbrglm.fit, which uses its elements as arguments to glm.control: the latter provides defaults. If mbr.trace=TRUE, calls to cat produce the iteration number, the parameter estimates and the current value of the modified scores for each iteration.mbrglm.fit, the fitting procedure used by
mbrglm.